/*
CANADUINO® Wi-Fi Relay Module with ESP-01
SKU 26766
EAN 4260474037667
https://universal-solder.ca/26766
*/

// Make sure you installed the WiFi library
// Select "Generic ESP8266 Module" in the IDE
#include <ESP8266WiFi.h>

// Replace with the network credentials of your choice
// The softAP IP address is typically 192.168.4.1
const char* ssid     = "CANADUINO_WiFi_Relay";
const char* password = "oniudanac";

String output0State = "off";

// Assign output variables to GPIO pins
const int output0 = 0;

WiFiServer server(80);

String header;


void setup() {
  
  // initialize serial connection for debugging
  Serial.begin(115200);

  // Initialize the output variables as outputs
  pinMode(output0, OUTPUT);
 
  // Set output to high because relay is LOW-active
  digitalWrite(output0, HIGH);


  // Connect to Wi-Fi network uwing SSID and password
  Serial.print("Setting AP (Access Point)…");
  // Remove the parameter "password" if you want an open Access Point
  WiFi.softAP(ssid, password);

  IPAddress IP = WiFi.softAPIP();
  Serial.print("AP IP address: ");
  Serial.println(IP);
  
  server.begin();
}

void loop(){
  WiFiClient client = server.available();  

  if (client) {                             
    Serial.println("New Client.");          
    String currentLine = "";                
    while (client.connected()) {            
      if (client.available()) {             
        char c = client.read();             
        Serial.write(c);                    
        header += c;
        if (c == '\n') {                    
          if (currentLine.length() == 0) {
 
            client.println("HTTP/1.1 200 OK");
            client.println("Content-type:text/html");
            client.println("Connection: close");
            client.println();
            

            if (header.indexOf("GET /0/on") >= 0) 
            {
              Serial.println("GPIO 0 on");
              output0State = "on";
              digitalWrite(output0, LOW);
            } 
            else if (header.indexOf("GET /0/off") >= 0) 
            {
              Serial.println("GPIO 0 off");
              output0State = "off";
              digitalWrite(output0, HIGH);
            }
          
           
            // Display the HTML web page
            client.println("<!DOCTYPE html><html>");
            client.println("<head><meta name=\"viewport\" content=\"width=device-width, initial-scale=1\">");
            client.println("<link rel=\"icon\" href=\"data:,\">");
            client.println("<style>html { font-family: Helvetica; display: inline-block; margin: 0px auto; text-align: center;}");
            client.println(".button { background-color: #007700; border: none; color: white; padding: 16px 40px;");
            client.println("text-decoration: none; font-size: 30px; margin: 2px; cursor: pointer;}");
            client.println(".button2 {background-color: #770000;}</style></head>");
            
            // Web Page Heading
            client.println("<body><h3>CANADUINO ESP-01 WiFi Relay</h3>");
            
            client.println("<br>");
            
            // Display current state, and ON/OFF buttons for GPIO 0  
            client.println("<p>Relay is " + output0State + "</p>");
            // If the output0State is off, it displays the ON button       
            if (output0State=="off") {
              client.println("<p><a href=\"/0/on\"><button class=\"button\">ON</button></a></p>");
            } else {
              client.println("<p><a href=\"/0/off\"><button class=\"button button2\">OFF</button></a></p>");
            } 
            client.println("<br>");
            client.println("<h6>UNIVERSAL-SOLDER Electronics Ltd, Canada</h6>");
            client.println("</body></html>");
            client.println();
            break;
          } else { 
            currentLine = "";
          }
        } else if (c != '\r') {  
          currentLine += c;      
        }
      }
    }
    header = "";
    client.stop();
    Serial.println("Client disconnected.");
    Serial.println("");
  }
}
